==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi@gmail.com>
 * @author SandorTIHANYI <stihanyi@gmail.com>
 */
$lang['menu']                  = 'Felhasználók kezelése';
$lang['noauth']                = '(A felhasználói azonosítás nem működik.)';
$lang['nosupport']             = '(A felhasználók kezelése nem támogatott.)';
$lang['badauth']               = 'nem érvényes authentikációs technika';
$lang['user_id']               = 'Felhasználó azonosító';
$lang['user_pass']             = 'Jelszó';
$lang['user_name']             = 'Név';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Csoportok';
$lang['field']                 = 'Mező';
$lang['value']                 = 'Érték';
$lang['add']                   = 'Hozzáadás';
$lang['delete']                = 'Törlés';
$lang['delete_selected']       = 'Kiválasztottak törlése';
$lang['edit']                  = 'Szerkesztés';
$lang['edit_prompt']           = 'A felhasználó szerkesztése';
$lang['modify']                = 'Változások mentése';
$lang['search']                = 'Keresés';
$lang['search_prompt']         = 'Keresés';
$lang['clear']                 = 'Keresési szűrés törlése';
$lang['filter']                = 'Szűrés';
$lang['summary']               = '%1$d-%2$d. felhasználókat mutatom a(z) %3$d megtalált felhasználóból. %4$d felhasználó van összesen.';
$lang['nonefound']             = 'Nem találtam ilyen felhasználót. %d felhasználó van összesen.';
$lang['delete_ok']             = '%d felhasználó törölve.';
$lang['delete_fail']           = '%d felhasználót nem sikerült törölni.';
$lang['update_ok']             = 'A felhasználó adatait sikeresen elmentettem.';
$lang['update_fail']           = 'A felhasználó adatainak mentése nem sikerült.';
$lang['update_exists']         = 'A felhasználói azonosító változtatása nem sikerült, a megadott azonosító (%s) már létezik. (A többi változtatás mentve.)';
$lang['start']                 = 'első';
$lang['prev']                  = 'előző';
$lang['next']                  = 'következő';
$lang['last']                  = 'utolsó';
$lang['edit_usermissing']      = 'A kiválasztott felhasználót nem találom, a felhasználói nevét törölték vagy megváltoztatták.';
$lang['user_notify']           = 'Felhasználó értesítése';
$lang['note_notify']           = 'Csak akkor küld értesítő e-mailt, ha a felhasználó új jelszót kapott.';
$lang['note_group']            = 'Ha nincs csoport meghatározva, az új felhasználó az alapértelmezett csoportba (%s) kerül.';
$lang['add_ok']                = 'A felhasználó sikeresen hozzáadva.';
$lang['add_fail']              = 'A felhasználó hozzáadása nem sikerült.';
$lang['notify_ok']             = 'Értesítő levél elküldve.';
$lang['notify_fail']           = 'Nem sikerült az értesítő levelet elküldeni.';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 */
$lang['menu']                  = 'Felhasználók kezelése';
$lang['noauth']                = '(A felhasználói azonosítás nem működik.)';
$lang['nosupport']             = '(A felhasználók kezelése nem támogatott.)';
$lang['badauth']               = 'nem érvényes authentikációs technika';
$lang['user_id']               = 'Felhasználó azonosító';
$lang['user_pass']             = 'Jelszó';
$lang['user_name']             = 'Név';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Csoportok';
$lang['field']                 = 'Mező';
$lang['value']                 = 'Érték';
$lang['add']                   = 'Hozzáadás';
$lang['delete']                = 'Törlés';
$lang['delete_selected']       = 'Kiválasztottak törlése';
$lang['edit']                  = 'Szerkesztés';
$lang['edit_prompt']           = 'A felhasználó szerkesztése';
$lang['modify']                = 'Változások mentése';
$lang['search']                = 'Keresés';
$lang['search_prompt']         = 'Keresés';
$lang['clear']                 = 'Keresési szűrés törlése';
$lang['filter']                = 'Szűrés';
$lang['summary']               = '%1$d-%2$d. felhasználókat mutatom a(z) %3$d megtalált felhasználóból. %4$d felhasználó van összesen.';
$lang['nonefound']             = 'Nem találtam ilyen felhasználót. %d felhasználó van összesen.';
$lang['delete_ok']             = '%d felhasználó törölve.';
$lang['delete_fail']           = '%d felhasználót nem sikerült törölni.';
$lang['update_ok']             = 'A felhasználó adatait sikeresen elmentettem.';
$lang['update_fail']           = 'A felhasználó adatainak mentése nem sikerült.';
$lang['update_exists']         = 'A felhasználói azonosító változtatása nem sikerült, a megadott azonosító (%s) már létezik. (A többi változtatás mentve.)';
$lang['start']                 = 'első';
$lang['prev']                  = 'előző';
$lang['next']                  = 'következő';
$lang['last']                  = 'utolsó';
$lang['edit_usermissing']      = 'A kiválasztott felhasználót nem találom, a felhasználói nevét törölték vagy megváltoztatták.';
$lang['user_notify']           = 'Felhasználó értesítése';
$lang['note_notify']           = 'Csak akkor küld értesítő e-mailt, ha a felhasználó új jelszót kapott.';
$lang['note_group']            = 'Ha nincs csoport meghatározva, az új felhasználó az alapértelmezett csoportba (%s) kerül.';
$lang['note_pass']             = 'Ha a baloldali mező üres, és a felhasználó értesítés aktív, akkor generált jelszó lesz.';
$lang['add_ok']                = 'A felhasználó sikeresen hozzáadva.';
$lang['add_fail']              = 'A felhasználó hozzáadása nem sikerült.';
$lang['notify_ok']             = 'Értesítő levél elküldve.';
$lang['notify_fail']           = 'Nem sikerült az értesítő levelet elküldeni.';
